clear all
version 16.1

* cd "enter desired path"

log using log_file, replace

global data "data.dta"

mkdir ./results
mkdir ./results/cont
mkdir ./results/deg
mkdir ./results/epr_ethnic_degraded
mkdir ./results/epr_ethnic_raw
mkdir ./results/mig

//////////////////////////////////////////////////////////
///////// Program for estimation and graphs //////////////
//////////////////////////////////////////////////////////
cap program drop est

program est

	syntax varlist(numeric ts fv), type(string) // depend. var, domestic dem., neighbor. dem, controls
	gettoken dv varlist2 : varlist 
	gettoken domdem varlist3 : varlist2
	gettoken neighdem varlist4 : varlist3
	gettoken domy varlist5 : varlist4
	gettoken neighy cont: varlist5

	sort ccode year 
	xtset ccode year, yearly

	di "Dependent variable: `dv'"
	di "Domestic democracy variable: `domdem'"
	di "Neighboring democracy variable: `neighdem'"

	if !inlist("`type'", "nb", "linear", "logit"){
		display as error "type must be logit, nb or linear"
		exit
	}

	if "`type'" == "nb"{

		qui sum `neighdem'
		local min11 = round(`r(min)', .1)
		local max11 = round(`r(max)', .1)
		local min1 = `r(min)'
		local max1 = `r(max)'
		qui sum `domdem'
		local min22 = round(`r(min)', .1)
		local max22 = round(`r(max)', .1)
		local min2 = `r(min)'
		local max2 = `r(max)'

		cap noi xtnbreg `dv' i.year l1`dv' c.`domdem'##c.`neighdem' c.`domdem'#c.`domdem' c.`domy'##c.`neighy' `cont' i.conf##c.d_n_conf, fe 
		qui sum year if e(sample)
		local ymin = `r(min)'
		local ymax = `r(max)' 
		qui distinct ccode if e(sample)
		cap noi outreg2 using `neighdem'.xml, excel drop(i.year) dec(2) adds(Year_min, `ymin', Year_max, `ymax', N_ccode, `r(ndistinct)')

		cap qui margins, dydx(`domdem') at(`neighdem'=(`min1'(.05)`max1')) predict(iru0) atmeans
		cap qui marginsplot, recastci(rarea) ciopt(color(gray%30)) recast(line) ylab(,nogrid) yline(0, lp(dash) lcol(black)) graphregion(col(white)) title("Domestic democracy") ytitle("Marginal effect") /// 
			xtitle("Average democracy level of neighboring countries") xlab(-0.6(.2)1.4) level(90) name(dom, replace) 

		cap qui margins, dydx(`neighdem') at(`domdem'=(`min2'(.05)`max2')) predict(iru0)
		cap qui marginsplot, recastci(rarea) ciopt(color(gray%30)) recast(line) ylab(,nogrid) yline(0, lp(dash) lcol(black)) graphregion(col(white)) title("Neighboring democracy") ytitle("") /// 
			xtitle("Domestic democracy level") xlab(`min22'(.1)`max22') level(90) name(neigh, replace)

		cap noi graph combine dom neigh, ycommon  graphregion(color(white))
		cap noi graph export `dv'.pdf, replace

		** no lag

		cap noi xtnbreg `dv' i.year c.`domdem'##c.`neighdem' c.`domdem'#c.`domdem' c.`domy'##c.`neighy' `cont' i.conf##c.d_n_conf, fe 
		qui sum year if e(sample)
		local ymin = `r(min)'
		local ymax = `r(max)'
		qui distinct ccode if e(sample)
		cap noi outreg2 using `neighdem'.xml, excel drop(i.year) dec(2) adds(Year_min, `ymin', Year_max, `ymax', N_ccode, `r(ndistinct)')

	}


	if "`type'" == "linear"{

		if ("`neighdem'" == "n_nxpolity_deg") {

			xtreg `dv' i.year l1`dv' `domdem' `neighdem' `domy' `neighy' `cont', fe robust
			qui sum year if e(sample)
			local ymin = `r(min)'
			local ymax = `r(max)' 
			qui distinct ccode if e(sample)
			cap noi outreg2 using `neighdem'.xml, excel drop(i.year) dec(2) adds(Year_min, `ymin', Year_max, `ymax', N_ccode, `r(ndistinct)')

			xtreg `dv' i.year l1`dv' c.`domdem'##c.`neighdem' c.`domy'##c.`neighy' `cont', fe robust
			qui sum year if e(sample)
			local ymin = `r(min)'
			local ymax = `r(max)' 
			qui distinct ccode if e(sample)
			cap noi outreg2 using `neighdem'.xml, excel drop(i.year) dec(2) adds(Year_min, `ymin', Year_max, `ymax', N_ccode, `r(ndistinct)')

		}

		xtreg `dv' i.year l1`dv' c.`domdem'##c.`neighdem' c.`domdem'#c.`domdem' c.`domy'##c.`neighy' `cont' i.conf##c.d_n_conf, fe robust
		qui sum year if e(sample)
		local ymin = `r(min)'
		local ymax = `r(max)' 
		qui distinct ccode if e(sample)
		cap noi outreg2 using `neighdem'.xml, excel drop(i.year) dec(2) adds(Year_min, `ymin', Year_max, `ymax', N_ccode, `r(ndistinct)')

		if ("`neighdem'" == "n_nxpolity_deg") {

			qui sum `neighdem'
			local min11 = round(`r(min)', .1)
			local max11 = round(`r(max)', .1)
			local min1 = `r(min)'
			local max1 = `r(max)'
			qui sum `domdem'
			local min22 = round(`r(min)', .1)
			local max22 = round(`r(max)', .1)
			local min2 = `r(min)'
			local max2 = `r(max)'

			qui margins, dydx(`domdem') at(`neighdem'=(`min1'(.05)`max1')) 
			qui marginsplot, recastci(rarea) recast(line) ciopt(color(gray%30)) ylab(,nogrid) yline(0, lp(dash) lcol(black)) graphregion(col(white)) title("Domestic democracy") ytitle("Marginal effect") /// 
				xtitle("Average democracy level of neighboring countries") level(90) xlab(-0.6(.2)1.4) name(dom, replace)

			qui margins, dydx(`neighdem') at(`domdem'=(`min2'(.05)`max2')) 
			qui marginsplot, recastci(rarea) recast(line) ciopt(color(gray%30)) ylab(,nogrid) yline(0, lp(dash) lcol(black)) graphregion(col(white)) title("Neighboring democracy") ytitle("") /// 
				xtitle("Domestic democracy level") level(90) xlab(`min22'(.1)`max22') name(neigh, replace)

			graph combine dom neigh, ycommon graphregion(color(white))
			graph export `dv'.pdf, replace

			** no lag

			xtreg `dv' i.year `domdem' `neighdem' `domy' `neighy' `cont', fe robust
			qui sum year if e(sample)
			local ymin = `r(min)'
			local ymax = `r(max)' 
			qui distinct ccode if e(sample)
			cap noi outreg2 using `neighdem'.xml, excel drop(i.year) dec(2) adds(Year_min, `ymin', Year_max, `ymax', N_ccode, `r(ndistinct)')

			xtreg `dv' i.year c.`domdem'##c.`neighdem' c.`domy'##c.`neighy' `cont', fe robust
			qui sum year if e(sample)
			local ymin = `r(min)'
			local ymax = `r(max)' 
			qui distinct ccode if e(sample)
			cap noi outreg2 using `neighdem'.xml, excel drop(i.year) dec(2) adds(Year_min, `ymin', Year_max, `ymax', N_ccode, `r(ndistinct)')

			xtreg `dv' i.year c.`domdem'##c.`neighdem' c.`domdem'#c.`domdem' c.`domy'##c.`neighy' `cont' i.conf##c.d_n_conf, fe robust
			qui sum year if e(sample)
			local ymin = `r(min)'
			local ymax = `r(max)' 
			qui distinct ccode if e(sample)
			cap noi outreg2 using `neighdem'.xml, excel drop(i.year) dec(2) adds(Year_min, `ymin', Year_max, `ymax', N_ccode, `r(ndistinct)')


			***** mean neigh dem dummy *****

			qui sum `domdem'
			local min22 = round(`r(min)', .1)
			local max22 = round(`r(max)', .1)
			local min2 = `r(min)'
			local max2 = `r(max)'

			xtreg `dv' i.year l1`dv' c.`domdem'##i.`neighdem'_omean_d c.`domdem'#c.`domdem' c.`domy'##c.`neighy' `cont' i.conf##c.d_n_conf, fe robust

			margins, dydx(`domdem') at(`neighdem'_omean_d=(0 1)) 
			marginsplot, ylab(,nogrid) yline(0, lp(dash) lcol(black)) graphregion(col(white)) title("Domestic democracy") ytitle("Marginal effect") /// 
				xtitle("Dem. level of neigh. below / above average") level(90) xlab(0 1) name(dom, replace)

			margins, dydx(`neighdem'_omean_d) at(`domdem'=(`min2'(.05)`max2')) 
			marginsplot, recastci(rarea) recast(line) ciopt(color(gray%30)) ylab(,nogrid) yline(0, lp(dash) lcol(black)) graphregion(col(white)) title("Neighboring democracy") ytitle("") /// 
				xtitle("Domestic democracy level") level(90) xlab(`min22'(.1)`max22') name(neigh, replace)

			graph combine dom neigh, ycommon graphregion(color(white))
			graph export `dv'_omean_d.pdf, replace

		}
	}

	if "`type'" == "logit"{

		local fname = "logit_"+"`neighdem'"

		sort ccode year 
		xtset ccode year, yearly


		if ("`neighdem'" == "n_nxpolity_deg") {

			xtlogit `dv' i.year l1`dv' `domdem' `neighdem' `domy' `neighy' `cont', fe 
			qui sum year if e(sample)
			local ymin = `r(min)'
			local ymax = `r(max)' 
			qui distinct ccode if e(sample)
			cap noi outreg2 using `fname'.xml, excel drop(i.year) ctitle("`dv', FE Logit") dec(2) adds(Year_min, `ymin', Year_max, `ymax', N_ccode, `r(ndistinct)')

			xtlogit `dv' i.year l1`dv' c.`domdem'##c.`neighdem' c.`domy'##c.`neighy' `cont', fe 
			qui sum year if e(sample)
			local ymin = `r(min)'
			local ymax = `r(max)' 
			qui distinct ccode if e(sample)
			cap noi outreg2 using `fname'.xml, excel drop(i.year) ctitle("`dv', FE Logit") dec(2) adds(Year_min, `ymin', Year_max, `ymax', N_ccode, `r(ndistinct)')

			xtlogit `dv' i.year l1`dv' c.`domdem'##c.`neighdem' c.`domdem'#c.`domdem' c.`domy'##c.`neighy' `cont' i.conf##c.d_n_conf, fe 
			qui sum year if e(sample)
			local ymin = `r(min)'
			local ymax = `r(max)' 
			qui distinct ccode if e(sample)
			cap noi outreg2 using `fname'.xml, excel drop(i.year) ctitle("`dv', FE Logit") dec(2) adds(Year_min, `ymin', Year_max, `ymax', N_ccode, `r(ndistinct)')

			qui sum `neighdem'
			local min11 = round(`r(min)', .1)
			local max11 = round(`r(max)', .1)
			local min1 = `r(min)'
			local max1 = `r(max)'
			qui sum `domdem'
			local min22 = round(`r(min)', .1)
			local max22 = round(`r(max)', .1)
			local min2 = `r(min)'
			local max2 = `r(max)'

		}

		logit `dv' i.year l1`dv' c.`domdem'##c.`neighdem' c.`domdem'#c.`domdem' c.`domy'##c.`neighy' `cont' i.conf##c.d_n_conf, cluster(ccode)
		qui sum year if e(sample)
		local ymin = `r(min)'
		local ymax = `r(max)'
		qui distinct ccode if e(sample)
		cap noi outreg2 using `fname'.xml, excel drop(i.year) ctitle("`dv', Logit") dec(2) adds(Year_min, `ymin', Year_max, `ymax', N_ccode, `r(ndistinct)')

		if ("`neighdem'" == "n_nxpolity_deg") {


			qui margins, dydx(`domdem') at(`neighdem'=(`min1'(.05)`max1'))  
			qui marginsplot, recastci(rarea) recast(line) ciopt(color(gray%30)) ylab(,nogrid) yline(0, lp(dash) lcol(black)) graphregion(col(white)) title("Domestic democracy") ytitle("Marginal effect") /// 
				xtitle("Average democracy level of neighboring countries") level(90) xlab(-0.6(.2)1.4) name(dom, replace)

			qui margins, dydx(`neighdem') at(`domdem'=(`min2'(.05)`max2')) 
			qui marginsplot, recastci(rarea) recast(line) ciopt(color(gray%30)) ylab(,nogrid) yline(0, lp(dash) lcol(black)) graphregion(col(white)) title("Neighboring democracy") ytitle("") /// 
				xtitle("Domestic democracy level") level(90) xlab(`min22'(.1)`max22') name(neigh, replace)

			graph combine dom neigh, ycommon graphregion(color(white))
			graph export `dv'.pdf, replace


			** no lag

			xtlogit `dv' i.year `domdem' `neighdem' `domy' `neighy' `cont', fe 
			qui sum year if e(sample)
			local ymin = `r(min)'
			local ymax = `r(max)'
			qui distinct ccode if e(sample)
			cap noi outreg2 using `fname'.xml, excel drop(i.year) ctitle("`dv', FE Logit") dec(2) adds(Year_min, `ymin', Year_max, `ymax', N_ccode, `r(ndistinct)')

			xtlogit `dv' i.year c.`domdem'##c.`neighdem' c.`domy'##c.`neighy' `cont', fe 
			qui sum year if e(sample)
			local ymin = `r(min)'
			local ymax = `r(max)' 
			qui distinct ccode if e(sample)
			cap noi outreg2 using `fname'.xml, excel drop(i.year) ctitle("`dv', FE Logit") dec(2) adds(Year_min, `ymin', Year_max, `ymax', N_ccode, `r(ndistinct)')

			xtlogit `dv' i.year c.`domdem'##c.`neighdem' c.`domdem'#c.`domdem' c.`domy'##c.`neighy' `cont' i.conf##c.d_n_conf, fe 
			qui sum year if e(sample)
			local ymin = `r(min)'
			local ymax = `r(max)' 
			qui distinct ccode if e(sample)
			cap noi outreg2 using `fname'.xml, excel drop(i.year) ctitle("`dv', FE Logit") dec(2) adds(Year_min, `ymin', Year_max, `ymax', N_ccode, `r(ndistinct)')	
			
			logit `dv' i.year c.`domdem'##c.`neighdem' c.`domdem'#c.`domdem' c.`domy'##c.`neighy' `cont' i.conf##c.d_n_conf, cluster(ccode)
			qui sum year if e(sample)
			local ymin = `r(min)'
			local ymax = `r(max)'
			qui distinct ccode if e(sample)
			cap noi outreg2 using `fname'.xml, excel drop(i.year) ctitle("`dv', Logit") dec(2) adds(Year_min, `ymin', Year_max, `ymax', N_ccode, `r(ndistinct)')


			***** mean neigh dem dummy *****
			qui sum `domdem'
			local min22 = round(`r(min)', .1)
			local max22 = round(`r(max)', .1)
			local min2 = `r(min)'
			local max2 = `r(max)'

			qui logit `dv' i.year l1`dv' c.`domdem'##i.`neighdem'_omean_d  c.`domdem'#c.`domdem' c.`domy'##c.`neighy' `cont' i.conf##c.d_n_conf, cluster(ccode)

			qui margins, dydx(`domdem') at(`neighdem'_omean_d =(0 1))  
			qui marginsplot, ylab(,nogrid) yline(0, lp(dash) lcol(black)) graphregion(col(white)) title("Domestic democracy") ytitle("Marginal effect") /// 
				xtitle("Dem. level of neigh. below / above average") level(90) xlab(0 1) name(dom, replace)

			qui margins, dydx(`neighdem'_omean_d) at(`domdem'=(`min2'(.05)`max2')) 
			qui marginsplot, recastci(rarea) recast(line) ciopt(color(gray%30)) ylab(,nogrid) yline(0, lp(dash) lcol(black)) graphregion(col(white)) title("Neighboring democracy") ytitle("") /// 
				xtitle("Domestic democracy level") level(90) xlab(`min22'(.1)`max22') name(neigh, replace)

			graph combine dom neigh, ycommon graphregion(color(white))
			graph export `dv'_omean_d.pdf, replace
		}	

	}


end


*** dependent variables
global dvcount antigov strikes riots
global dvlinear physint_mod amnesty statedept hrps
global dvsbinary d_antigov d_strikes d_riots

*** predictors
global moddeg              nxpolity n_nxpolity_deg lny lnn_y_deg lnpop youth 
global modcont             nxpolity n_nxpolity_cont lny lnn_y lnpop youth
global modmig              nxpolity n_nxpolity_mig lny lnn_y_mig_norm lnpop youth
global modeprethraw        nxpolity n_nxpolity_epr_raw lny lnn_y_epr_ethnic_raw lnpop youth
global modeprethdegraded   nxpolity n_nxpolity_epr_degraded lny lnn_y_epr_ethnic_degraded lnpop youth

//////////////////////////////////////////////////////////
//////////////////// Descriptives ////////////////////////
//////////////////////////////////////////////////////////
	use $data, clear

lab var n_nxpolity_deg "Degraded distance"
lab var n_nxpolity_cont "Direct contiguity"
lab var n_nxpolity_mig "Migrant stocks"
lab var n_nxpolity_epr_raw "Ethnic proximity"
lab var n_nxpolity_epr_degraded "Degraded ethnic proximity"

// table 1 online appendix
corr n_nxpolity_deg n_nxpolity_cont n_nxpolity_mig n_nxpolity_epr_raw n_nxpolity_epr_degraded

//////////////////////////////////////////////////////////
///////////// Regressions - Degraded distance ////////////
//////////////////////////////////////////////////////////
	use $data, clear

cd .\results\deg
cap erase n_nxpolity_deg.xml
cap erase n_nxpolity_deg.txt
cap erase logit_n_nxpolity_deg.xml
cap erase logit_n_nxpolity_deg.txt

// table 1 
*** Logit
foreach var of varlist $dvsbinary{
	est `var' $moddeg, type(logit)
}

// table 2 
*** Linear FE
foreach var of varlist $dvlinear{
	est `var' $moddeg, type(linear)
}

// table 3 online appendix
*** Negative binomial FE
foreach var of varlist $dvcount{
	est `var' $moddeg, type(nb)
}

// table 3 online appendix
*** Latent protest indicators ***
est latent_prot $moddeg, type(linear) 

window manage close graph _all
cd ..\..

//////////////////////////////////////////////////////////
///////////// Regressions - Direct contiguity ////////////
//////////////////////////////////////////////////////////
// table 2 online appendix
use $data, clear

cap mkdir .\results\cont
cd .\results\cont
cap erase n_nxpolity_cont.xml
cap erase n_nxpolity_cont.txt
cap erase logit_n_nxpolity_cont.xml
cap erase logit_n_nxpolity_cont.txt

*** Linear FE
foreach var of varlist $dvlinear{
	est `var' $modcont, type(linear)
}

*** Logit
foreach var of varlist $dvsbinary{
	est `var' $modcont, type(logit)
}

window manage close graph _all
cd ..\..


//////////////////////////////////////////////////////////
////////////// Regressions - Migrant stocks //////////////
//////////////////////////////////////////////////////////
// table 2 online appendix
use $data, clear

cap mkdir .\results\mig
cd .\results\mig
cap erase n_nxpolity_mig.xml
cap erase n_nxpolity_mig.txt
cap erase logit_n_nxpolity_mig.xml
cap erase logit_n_nxpolity_mig.txt

*** Linear FE
foreach var of varlist $dvlinear{
	est `var' $modmig, type(linear)
}

*** Logit
foreach var of varlist $dvsbinary{
	est `var' $modmig, type(logit)
}

window manage close graph _all
cd ..\..


//////////////////////////////////////////////////////////
///////////// Regressions - EPR ethnic (raw) /////////////
//////////////////////////////////////////////////////////
// table 2 online appendix
use $data, clear

cap mkdir .\results\epr_ethnic_raw
cd .\results\epr_ethnic_raw
cap erase n_nxpolity_epr_raw.xml
cap erase n_nxpolity_epr_raw.txt
cap erase logit_n_nxpolity_epr_raw.xml
cap erase logit_n_nxpolity_epr_raw.txt

*** Linear FE
foreach var of varlist $dvlinear{
	est `var' $modeprethraw, type(linear)
}

*** Logit
foreach var of varlist $dvsbinary{
	est `var' $modeprethraw, type(logit)
}

window manage close graph _all
cd ..\..


//////////////////////////////////////////////////////////
///////////// Regressions - EPR ethnic (degraded) ////////
//////////////////////////////////////////////////////////
// table 2 online appendix
use $data, clear

cap mkdir .\results\epr_ethnic_degraded
cd .\results\epr_ethnic_degraded
cap erase n_nxpolity_epr_degraded.xml
cap erase n_nxpolity_epr_degraded.txt
cap erase logit_n_nxpolity_epr_degraded.xml
cap erase logit_n_nxpolity_epr_degraded.txt

*** Linear FE
foreach var of varlist $dvlinear{
	est `var' $modeprethdegraded, type(linear)
}

*** Logit
foreach var of varlist $dvsbinary{
	est `var' $modeprethdegraded, type(logit)
}

window manage close graph _all
cd ..\..


log close
